@@ -1,6 +1,6 @@
 ### Contour to SpatialLinesDataFrame conversion if
 ### (!isGeneric('outerProbability')){
-setGeneric("raster2contour", function(x, ...) {standardGeneric("raster2contour")})  #bart kami do we want to skip maxpixels? if not than there would be no reason to have a different function name to rasterToContour
+setGeneric("raster2contour", function(x, ...) {standardGeneric("raster2contour")})  
 # }
 setMethod(f = "raster2contour", 
           signature = c(x = "RasterLayer"),
